@@ -1,6 +1,6 @@
 module DiasporaFederation
   module Discovery
-    # This class provides the means of generating an parsing account data to and
+    # This class provides the means of generating and parsing account data to and
     # from the hCard format.
     # hCard is based on +RFC 2426+ (vCard) which got superseded by +RFC 6350+.
     # There is a draft for a new h-card format specification, that makes use of
@@ -46,9 +46,9 @@ module DiasporaFederation
       property :guid
 
       # @!attribute [r] nickname
-      #   the first part of the diaspora ID
+      #   The first part of the diaspora* ID
       #   @return [String] nickname
-      property :nickname
+      property :nickname, default: nil
 
       # @!attribute [r] full_name
       #   @return [String] display name of the user
@@ -56,11 +56,11 @@ module DiasporaFederation
 
       # @!attribute [r] url
       #   @deprecated should be changed to the profile url. The pod url is in
-      #     the WebFinger (see {WebFinger#seed_url}, will affect older Diaspora*
+      #     the WebFinger (see {WebFinger#seed_url}, will affect older diaspora*
       #     installations).
       #
       #   @return [String] link to the pod
-      property :url
+      property :url, default: nil
 
       # @!attribute [r] public_key
       #   When a user is created on the pod, the pod MUST generate a pgp keypair
@@ -83,7 +83,7 @@ module DiasporaFederation
 
       # @!attribute [r] first_name
       #   @deprecated We decided to only use one name field, these should be removed
-      #     in later iterations (will affect older Diaspora* installations).
+      #     in later iterations (will affect older diaspora* installations).
       #
       #   @see #full_name
       #   @return [String] first name
@@ -91,7 +91,7 @@ module DiasporaFederation
 
       # @!attribute [r] last_name
       #   @deprecated We decided to only use one name field, these should be removed
-      #     in later iterations (will affect older Diaspora* installations).
+      #     in later iterations (will affect older diaspora* installations).
       #
       #   @see #full_name
       #   @return [String] last name
@@ -100,7 +100,7 @@ module DiasporaFederation
       # @!attribute [r] searchable
       #   @deprecated As this is a simple property, consider move to WebFinger instead
       #     of HCard. vCard has no comparable field for this information, but
-      #     Webfinger may declare arbitrary properties (will affect older Diaspora*
+      #     Webfinger may declare arbitrary properties (will affect older diaspora*
       #     installations).
       #
       #   flag if a user is searchable by name
@@ -152,7 +152,7 @@ module DiasporaFederation
         builder.doc.to_xhtml(indent: 2, indent_text: " ")
       end
 
-      # Creates a new HCard instance from the given HTML string.
+      # Creates a new HCard instance from the given HTML string
       # @param html_string [String] HTML string
       # @return [HCard] HCard instance
       # @raise [InvalidData] if the HTML string is invalid or incomplete
@@ -163,7 +163,6 @@ module DiasporaFederation
           guid:             guid_from_doc(doc),
           nickname:         content_from_doc(doc, :nickname),
           full_name:        content_from_doc(doc, :fn),
-          url:              element_from_doc(doc, :url)["href"],
           photo_large_url:  photo_from_doc(doc, :photo),
           photo_medium_url: photo_from_doc(doc, :photo_medium),
           photo_small_url:  photo_from_doc(doc, :photo_small),
@@ -220,7 +219,7 @@ module DiasporaFederation
         end
       end
 
-      # Calls {HCard#add_property} for a simple text property.
+      # Calls {HCard#add_property} for a simple text property
       # @param container [Nokogiri::XML::Element] parent element
       # @param name [Symbol] property name
       # @param class_name [String] HTML class name
@@ -253,43 +252,36 @@ module DiasporaFederation
       # HTML document.
       # @param [LibXML::XML::Document] doc HTML document
       # @return [Boolean] validation result
-      def self.html_document_complete?(doc)
-        !(doc.at_css(SELECTORS[:fn]).nil? || doc.at_css(SELECTORS[:nickname]).nil? ||
-          doc.at_css(SELECTORS[:url]).nil? || doc.at_css(SELECTORS[:photo]).nil?)
+      private_class_method def self.html_document_complete?(doc)
+        !(doc.at_css(SELECTORS[:fn]).nil? || doc.at_css(SELECTORS[:photo]).nil?)
       end
-      private_class_method :html_document_complete?
 
-      def self.parse_html_and_validate(html_string)
+      private_class_method def self.parse_html_and_validate(html_string)
         raise ArgumentError, "hcard html is not a string" unless html_string.instance_of?(String)
 
         doc = Nokogiri::HTML::Document.parse(html_string)
         raise InvalidData, "hcard html incomplete" unless html_document_complete?(doc)
         doc
       end
-      private_class_method :parse_html_and_validate
 
-      def self.element_from_doc(doc, selector)
+      private_class_method def self.element_from_doc(doc, selector)
         doc.at_css(SELECTORS[selector])
       end
-      private_class_method :element_from_doc
 
-      def self.content_from_doc(doc, content_selector)
-        element_from_doc(doc, content_selector).content
+      private_class_method def self.content_from_doc(doc, content_selector)
+        element_from_doc(doc, content_selector).try(:content)
       end
-      private_class_method :content_from_doc
 
-      def self.photo_from_doc(doc, photo_selector)
+      private_class_method def self.photo_from_doc(doc, photo_selector)
         element_from_doc(doc, photo_selector)["src"]
       end
-      private_class_method :photo_from_doc
 
       # @deprecated hack for old hcard
       # @todo remove this when all pods have the new generator
-      def self.guid_from_doc(doc)
+      private_class_method def self.guid_from_doc(doc)
         uid_element = element_from_doc(doc, :uid)
         uid_element.content unless uid_element[:class].include? "nickname"
       end
-      private_class_method :guid_from_doc
     end
   end
 end
