@@ -4,7 +4,7 @@ module DiasporaFederation
     # Generates and parses Host Meta documents.
     #
     # This is a minimal implementation of the standard, only to the degree of what
-    # is used for the purposes of the Diaspora* protocol. (e.g. WebFinger)
+    # is used for the purposes of the diaspora* protocol. (e.g. WebFinger)
     #
     # @example Creating a Host Meta document
     #   doc = HostMeta.from_base_url("https://pod.example.tld/")
@@ -19,7 +19,7 @@ module DiasporaFederation
     class HostMeta
       private_class_method :new
 
-      # create a new host-meta instance
+      # Creates a new host-meta instance
       # @param [String] webfinger_url the webfinger-url
       def initialize(webfinger_url)
         @webfinger_url = webfinger_url
@@ -75,19 +75,17 @@ module DiasporaFederation
       # Applies some basic sanity-checking to the given URL
       # @param [String] url validation subject
       # @return [Boolean] validation result
-      def self.webfinger_url_valid?(url)
+      private_class_method def self.webfinger_url_valid?(url)
         !url.nil? && url.instance_of?(String) && url =~ %r{^https?:\/\/.*\/.*\{uri\}.*}i
       end
-      private_class_method :webfinger_url_valid?
 
       # Gets the webfinger url from an XRD data structure
       # @param [Hash] data extracted data
       # @return [String] webfinger url
-      def self.webfinger_url_from_xrd(data)
+      private_class_method def self.webfinger_url_from_xrd(data)
         link = data[:links].find {|l| l[:rel] == "lrdd" }
         return link[:template] unless link.nil?
       end
-      private_class_method :webfinger_url_from_xrd
     end
   end
 end
