@@ -1,9 +1,7 @@
 module DiasporaFederation
   module Discovery
-    # The WebFinger document used for Diaspora* user discovery is based on an older
-    # draft of the specification you can find in the wiki of the "webfinger" project
-    # on {http://code.google.com/p/webfinger/wiki/WebFingerProtocol Google Code}
-    # (from around 2010).
+    # The WebFinger document used for diaspora* user discovery is based on an
+    # {http://tools.ietf.org/html/draft-jones-appsawg-webfinger older draft of the specification}.
     #
     # In the meantime an actual RFC draft has been in development, which should
     # serve as a base for all future changes of this implementation.
@@ -30,7 +28,6 @@ module DiasporaFederation
     #
     # @see http://tools.ietf.org/html/draft-jones-appsawg-webfinger "WebFinger" -
     #   current draft
-    # @see http://code.google.com/p/webfinger/wiki/CommonLinkRelations
     # @see http://www.iana.org/assignments/link-relations/link-relations.xhtml
     #   official list of IANA link relations
     class WebFinger < Entity
@@ -58,7 +55,7 @@ module DiasporaFederation
       property :profile_url
 
       # @!attribute [r] atom_url
-      #   This atom feed is an Activity Stream of the user's public posts. Diaspora
+      #   This atom feed is an Activity Stream of the user's public posts. diaspora*
       #   pods SHOULD publish an Activity Stream of public posts, but there is
       #   currently no requirement to be able to read Activity Streams.
       #   @see http://activitystrea.ms/ Activity Streams specification
@@ -71,7 +68,7 @@ module DiasporaFederation
       # @!attribute [r] salmon_url
       #   @note could be nil
       #   @return [String] salmon endpoint url
-      #   @see http://salmon-protocol.googlecode.com/svn/trunk/draft-panzer-salmon-00.html#SMLR
+      #   @see https://cdn.rawgit.com/salmon-protocol/salmon-protocol/master/draft-panzer-salmon-00.html#SMLR
       #     Panzer draft for Salmon, paragraph 3.3
       property :salmon_url
 
@@ -82,7 +79,7 @@ module DiasporaFederation
       # @!attribute [r] guid
       #   @deprecated Either convert these to +Property+ elements or move to the
       #     +hCard+, which actually has fields for an +UID+ defined in the +vCard+
-      #     specification (will affect older Diaspora* installations).
+      #     specification (will affect older diaspora* installations).
       #
       #   @see HCard#guid
       #   @see Entities::Person#guid
@@ -92,7 +89,7 @@ module DiasporaFederation
       # @!attribute [r] public_key
       #   @deprecated Either convert these to +Property+ elements or move to the
       #     +hCard+, which actually has fields for an +KEY+ defined in the +vCard+
-      #     specification (will affect older Diaspora* installations).
+      #     specification (will affect older diaspora* installations).
       #
       #   @see HCard#public_key
       #
@@ -111,7 +108,7 @@ module DiasporaFederation
 
       # @deprecated This should be a +Property+ or moved to the +hCard+, but +Link+
       #   is inappropriate according to the specification (will affect older
-      #   Diaspora* installations).
+      #   diaspora* installations).
       # +guid+ link relation
       REL_GUID = "http://joindiaspora.com/guid".freeze
 
@@ -130,11 +127,11 @@ module DiasporaFederation
 
       # @deprecated This should be a +Property+ or moved to the +hcard+, but +Link+
       #   is inappropriate according to the specification (will affect older
-      #   Diaspora* installations).
+      #   diaspora* installations).
       # +pubkey+ link relation
       REL_PUBKEY = "diaspora-public-key".freeze
 
-      # Create the XML string from the current WebFinger instance
+      # Creates the XML string from the current WebFinger instance
       # @return [String] XML string
       def to_xml
         doc = XrdDocument.new
@@ -146,7 +143,7 @@ module DiasporaFederation
         doc.to_xml
       end
 
-      # Create a WebFinger instance from the given XML string.
+      # Creates a WebFinger instance from the given XML string
       # @param [String] webfinger_xml WebFinger XML string
       # @return [WebFinger] WebFinger instance
       # @raise [InvalidData] if the given XML string is invalid or incomplete
@@ -175,6 +172,11 @@ module DiasporaFederation
         )
       end
 
+      # @return [String] string representation of this object
+      def to_s
+        "WebFinger:#{acct_uri}"
+      end
+
       private
 
       # Parses the XML string to a Hash and does some rudimentary checking on
@@ -182,13 +184,12 @@ module DiasporaFederation
       # @param [String] webfinger_xml WebFinger XML string
       # @return [Hash] data XML data
       # @raise [InvalidData] if the given XML string is invalid or incomplete
-      def self.parse_xml_and_validate(webfinger_xml)
+      private_class_method def self.parse_xml_and_validate(webfinger_xml)
         XrdDocument.xml_data(webfinger_xml).tap do |data|
           valid = data.key?(:subject) && data.key?(:links)
           raise InvalidData, "webfinger xml is incomplete" unless valid
         end
       end
-      private_class_method :parse_xml_and_validate
 
       def add_links_to(doc)
         doc.links << {rel: REL_HCARD, type: "text/html", href: @hcard_url}
@@ -211,33 +212,29 @@ module DiasporaFederation
         ##################################
       end
 
-      def self.find_link(links, rel)
+      private_class_method def self.find_link(links, rel)
         links.find {|l| l[:rel] == rel }
       end
-      private_class_method :find_link
 
-      def self.parse_link(links, rel)
+      private_class_method def self.parse_link(links, rel)
         element = find_link(links, rel)
         element ? element[:href] : nil
       end
-      private_class_method :parse_link
 
-      def self.parse_link_template(links, rel)
+      private_class_method def self.parse_link_template(links, rel)
         element = find_link(links, rel)
         element ? element[:template] : nil
       end
-      private_class_method :parse_link_template
 
-      # this method is used to parse the alias_url from the XML.
+      # This method is used to parse the alias_url from the XML.
       # * redmatrix has sometimes no alias, return nil
       # * old pods had quotes around the alias url, this can be removed later
       # * friendica has two aliases and the first is with "acct:": return only an URL starting with http (or https)
-      def self.parse_alias(aliases)
+      private_class_method def self.parse_alias(aliases)
         return nil unless aliases
         # TODO: Old pods had quotes around alias. Remove the +map+ in next line, when all pods use this gem
         aliases.map {|a| a.gsub(/\A"|"\Z/, "") }.find {|a| a.start_with?("http") }
       end
-      private_class_method :parse_alias
     end
   end
 end
