@@ -1,13 +1,16 @@
 module DiasporaFederation
   module Entities
-    # this entity represents a comment to some kind of post (e.g. status message)
+    # This entity represents a comment to some kind of post (e.g. status message).
     #
     # @see Validators::CommentValidator
     class Comment < Entity
-      # old signature order
+      # Old signature order
       # @deprecated
       LEGACY_SIGNATURE_ORDER = %i(guid parent_guid text author).freeze
 
+      # The {Comment} parent is a {Post}
+      PARENT_TYPE = "Post".freeze
+
       include Relayable
 
       # @!attribute [r] text
@@ -15,15 +18,9 @@ module DiasporaFederation
       property :text
 
       # @!attribute [r] created_at
-      #   comment entity creation time
+      #   Comment entity creation time
       #   @return [Time] creation time
       property :created_at, default: -> { Time.now.utc }
-
-      # The {Comment} parent is a Post
-      # @return [String] parent type
-      def parent_type
-        "Post"
-      end
     end
   end
 end
