@@ -1,6 +1,6 @@
 module DiasporaFederation
   # +Entity+ is the base class for all other objects used to encapsulate data
-  # for federation messages in the Diaspora* network.
+  # for federation messages in the diaspora* network.
   # Entity fields are specified using a simple {PropertiesDSL DSL} as part of
   # the class definition.
   #
@@ -34,6 +34,11 @@ module DiasporaFederation
   #   are intended to be immutable data containers, only.
   class Entity
     extend PropertiesDSL
+    include Logging
+
+    # Invalid XML characters
+    # @see https://www.w3.org/TR/REC-xml/#charsets "Extensible Markup Language (XML) 1.0"
+    INVALID_XML_REGEX = /[^\x09\x0A\x0D\x20-\uD7FF\uE000-\uFFFD\u{10000}-\u{10FFFF}]/
 
     # Initializes the Entity with the given attribute hash and freezes the created
     # instance it returns.
@@ -50,27 +55,35 @@ module DiasporaFederation
     # @param [Hash] data entity data
     # @return [Entity] new instance
     def initialize(data)
+      logger.debug "create entity #{self.class} with data: #{data}"
       raise ArgumentError, "expected a Hash" unless data.is_a?(Hash)
+
       entity_data = self.class.resolv_aliases(data)
-      missing_props = self.class.missing_props(entity_data)
-      unless missing_props.empty?
-        raise ArgumentError, "missing required properties: #{missing_props.join(', ')}"
-      end
+      validate_missing_props(entity_data)
 
       self.class.default_values.merge(entity_data).each do |name, value|
-        instance_variable_set("@#{name}", nilify(value)) if setable?(name, value)
+        instance_variable_set("@#{name}", instantiate_nested(name, nilify(value))) if setable?(name, value)
       end
 
       freeze
       validate
     end
 
-    # Returns a Hash representing this Entity (attributes => values)
+    # Returns a Hash representing this Entity (attributes => values).
+    # Nested entities are also converted to a Hash.
     # @return [Hash] entity data (mostly equal to the hash used for initialization).
     def to_h
-      self.class.class_props.keys.each_with_object({}) do |prop, hash|
-        hash[prop] = public_send(prop)
-      end
+      properties.map {|key, value|
+        type = self.class.class_props[key]
+
+        if type == String || value.nil?
+          [key, value]
+        elsif type.instance_of?(Class)
+          [key, value.to_h]
+        elsif type.instance_of?(Array)
+          [key, value.map(&:to_h)]
+        end
+      }.to_h
     end
 
     # Returns the XML representation for this entity constructed out of
@@ -131,8 +144,18 @@ module DiasporaFederation
       Entities.const_get(class_name)
     end
 
+    # @return [String] string representation of this object
+    def to_s
+      "#{self.class.name.rpartition('::').last}#{":#{guid}" if respond_to?(:guid)}"
+    end
+
     private
 
+    def validate_missing_props(entity_data)
+      missing_props = self.class.missing_props(entity_data)
+      raise ValidationError, "missing required properties: #{missing_props.join(', ')}" unless missing_props.empty?
+    end
+
     def setable?(name, val)
       type = self.class.class_props[name]
       return false if type.nil? # property undefined
@@ -145,18 +168,30 @@ module DiasporaFederation
     end
 
     def setable_nested?(type, val)
-      type.is_a?(Class) && type.ancestors.include?(Entity) && val.is_a?(Entity)
+      type.instance_of?(Class) && type.ancestors.include?(Entity) && (val.is_a?(Entity) || val.is_a?(Hash))
     end
 
     def setable_multi?(type, val)
-      type.instance_of?(Array) && val.instance_of?(Array) && val.all? {|v| v.instance_of?(type.first) }
+      type.instance_of?(Array) && val.instance_of?(Array) &&
+        (val.all? {|v| v.instance_of?(type.first) } || val.all? {|v| v.instance_of?(Hash) })
     end
 
     def nilify(value)
-      return nil if value.respond_to?(:empty?) && value.empty?
+      return nil if value.respond_to?(:empty?) && value.empty? && !value.instance_of?(Array)
       value
     end
 
+    def instantiate_nested(name, value)
+      if value.instance_of?(Array)
+        return value unless value.first.instance_of?(Hash)
+        value.map {|hash| self.class.class_props[name].first.new(hash) }
+      elsif value.instance_of?(Hash)
+        self.class.class_props[name].new(value)
+      else
+        value
+      end
+    end
+
     def validate
       validator_name = "#{self.class.name.split('::').last}Validator"
       return unless Validators.const_defined? validator_name
@@ -173,8 +208,15 @@ module DiasporaFederation
       "Failed validation for properties: #{errors.join(' | ')}"
     end
 
+    # @return [Hash] hash with all properties
+    def properties
+      self.class.class_props.keys.each_with_object({}) do |prop, hash|
+        hash[prop] = public_send(prop)
+      end
+    end
+
     def xml_elements
-      Hash[to_h.map {|name, value| [name, self.class.class_props[name] == String ? value.to_s : value] }]
+      properties.map {|name, value| [name, self.class.class_props[name] == String ? value.to_s : value] }.to_h
     end
 
     def add_property_to_xml(doc, root_element, name, value)
@@ -183,35 +225,40 @@ module DiasporaFederation
       else
         # call #to_xml for each item and append to root
         [*value].compact.each do |item|
-          root_element << item.to_xml
+          child = item.to_xml
+          root_element << child if child
         end
       end
     end
 
-    # create simple node, fill it with text and append to root
+    # Create simple node, fill it with text and append to root
     def simple_node(doc, name, value)
       xml_name = self.class.xml_names[name]
       Nokogiri::XML::Element.new(xml_name ? xml_name.to_s : name, doc).tap do |node|
-        node.content = value unless value.empty?
+        node.content = value.gsub(INVALID_XML_REGEX, "\uFFFD") unless value.empty?
       end
     end
 
     # @param [Nokogiri::XML::Element] root_node xml nodes
     # @return [Entity] instance
-    def self.populate_entity(root_node)
-      entity_data = Hash[class_props.map {|name, type|
-        [name, parse_element_from_node(name, type, root_node)]
-      }]
+    private_class_method def self.populate_entity(root_node)
+      new(entity_data(root_node))
+    end
 
-      new(entity_data)
+    # @param [Nokogiri::XML::Element] root_node xml nodes
+    # @return [Hash] entity data
+    private_class_method def self.entity_data(root_node)
+      class_props.map {|name, type|
+        value = parse_element_from_node(name, type, root_node)
+        [name, value] if value
+      }.compact.to_h
     end
-    private_class_method :populate_entity
 
     # @param [String] name property name to parse
     # @param [Class] type target type to parse
     # @param [Nokogiri::XML::Element] root_node XML node to parse
     # @return [Object] parsed data
-    def self.parse_element_from_node(name, type, root_node)
+    private_class_method def self.parse_element_from_node(name, type, root_node)
       if type == String
         parse_string_from_node(name, root_node)
       elsif type.instance_of?(Array)
@@ -220,41 +267,37 @@ module DiasporaFederation
         parse_entity_from_node(type, root_node)
       end
     end
-    private_class_method :parse_element_from_node
 
-    # create simple entry in data hash
+    # Create simple entry in data hash
     #
     # @param [String] name xml tag to parse
     # @param [Nokogiri::XML::Element] root_node XML root_node to parse
     # @return [String] data
-    def self.parse_string_from_node(name, root_node)
+    private_class_method def self.parse_string_from_node(name, root_node)
       node = root_node.xpath(name.to_s)
       node = root_node.xpath(xml_names[name].to_s) if node.empty?
       node.first.text if node.any?
     end
-    private_class_method :parse_string_from_node
 
-    # create an entry in the data hash for the nested entity
+    # Create an entry in the data hash for the nested entity
     #
     # @param [Class] type target type to parse
     # @param [Nokogiri::XML::Element] root_node XML node to parse
     # @return [Entity] parsed child entity
-    def self.parse_entity_from_node(type, root_node)
+    private_class_method def self.parse_entity_from_node(type, root_node)
       node = root_node.xpath(type.entity_name)
-      type.from_xml(node.first) if node.any?
+      type.from_xml(node.first) if node.any? && node.first.children.any?
     end
-    private_class_method :parse_entity_from_node
 
-    # collect all nested children of that type and create an array in the data hash
+    # Collect all nested children of that type and create an array in the data hash
     #
     # @param [Class] type target type to parse
     # @param [Nokogiri::XML::Element] root_node XML node to parse
     # @return [Array<Entity>] array with parsed child entities
-    def self.parse_array_from_node(type, root_node)
+    private_class_method def self.parse_array_from_node(type, root_node)
       node = root_node.xpath(type.entity_name)
-      node.map {|child| type.from_xml(child) }
+      node.select {|child| child.children.any? }.map {|child| type.from_xml(child) } unless node.empty?
     end
-    private_class_method :parse_array_from_node
 
     # Raised, if entity is not valid
     class ValidationError < RuntimeError
