@@ -58,7 +58,7 @@ module DiasporaFederation
     # @param [Hash] data entity data
     # @return [Hash] hash with resolved aliases
     def resolv_aliases(data)
-      Hash[data.map {|name, value|
+      data.map {|name, value|
         if class_prop_aliases.has_key? name
           prop_name = class_prop_aliases[name]
           raise InvalidData, "only use '#{name}' OR '#{prop_name}'" if data.has_key? prop_name
@@ -66,7 +66,7 @@ module DiasporaFederation
         else
           [name, value]
         end
-      }]
+      }.to_h
     end
 
     # @return [Symbol] alias for the xml-generation/parsing
@@ -75,7 +75,7 @@ module DiasporaFederation
       @xml_names ||= {}
     end
 
-    # finds a property by +xml_name+ or +name+
+    # Finds a property by +xml_name+ or +name+
     # @param [String] xml_name name of the property from the received xml
     # @return [Hash] the property data
     def find_property_for_xml_name(xml_name)
@@ -114,14 +114,14 @@ module DiasporaFederation
       define_alias(name, opts[:alias]) if opts.has_key? :alias
     end
 
-    # checks if the name is a +Symbol+ or a +String+
+    # Checks if the name is a +Symbol+ or a +String+
     # @param [String, Symbol] name the name to check
     # @return [Boolean]
     def name_valid?(name)
       name.instance_of?(Symbol)
     end
 
-    # checks if the type extends {Entity}
+    # Checks if the type extends {Entity}
     # @param [Class] type the type to check
     # @return [Boolean]
     def type_valid?(type)
@@ -144,7 +144,9 @@ module DiasporaFederation
     # @param [Symbol] alias_name alias name
     def define_alias(name, alias_name)
       class_prop_aliases[alias_name] = name
+      # rubocop:disable Style/Alias
       instance_eval { alias_method alias_name, name }
+      # rubocop:enable Style/Alias
     end
 
     # Raised, if the name is of an unexpected type
