@@ -1,13 +1,13 @@
 module Validation
   module Rule
-    # Rule for validating the number of Diaspora* ids in a string.
+    # Rule for validating the number of diaspora* IDs in a string.
     # The evaluated string is split at ";" and the result will be counted.
     class DiasporaIdCount
-      # This rule must have a +maximum+ param
+      # This rule must have a +maximum+ param.
       # @return [Hash] params
       attr_reader :params
 
-      # create a new rule for a maximum diaspora id count validation
+      # Creates a new rule for a maximum diaspora* ID count validation
       # @param [Hash] params
       # @option params [Fixnum] :maximum maximum allowed id count
       def initialize(params)
@@ -28,7 +28,7 @@ module Validation
         ids = value.split(";")
         return false unless ids.count <= params[:maximum]
         ids.each do |id|
-          return false unless DiasporaId.new.valid_value?(id)
+          return false if DiasporaId::DIASPORA_ID.match(id).nil?
         end
         true
       end
