@@ -1,6 +1,6 @@
 module DiasporaFederation
   module Validators
-    # This validates a {Entities::StatusMessage}
+    # This validates a {Entities::StatusMessage}.
     class StatusMessageValidator < Validation::Validator
       include Validation
 
@@ -8,6 +8,10 @@ module DiasporaFederation
 
       rule :guid, :guid
 
+      rule :text, length: {maximum: 65_535}
+
+      rule :photos, :not_nil
+
       rule :public, :boolean
     end
   end
